#
# spec file for package python3-blosc
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-blosc
Version:        1.2.7
Release:        3.3
Summary:        Blosc data compressor for Python
License:        MIT
Group:          Development/Languages/Python
Url:            http://www.blosc.org/
Source:         http://pypi.python.org/packages/source/b/blosc/blosc-%{version}.tar.gz
BuildRequires:  blosc-devel
BuildRequires:  gcc-c++
BuildRequires:  python3-devel
BuildRequires:  python3-numpy
Requires:       blosc-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Blosc is a high performance compressor optimized for binary data in
Python.

%prep
%setup -q -n blosc-%{version}

%build
CFLAGS="%{optflags}" python3 setup.py build_ext --inplace --blosc=%{_prefix}

%install
python3 setup.py install --blosc=%{_prefix} --prefix=%{_prefix} --root=%{buildroot}

%check
PYTHONPATH="." python3 blosc/test.py

%files
%defattr(-,root,root,-)
%doc ANNOUNCE.rst README.rst LICENSES/*.txt RELEASE_NOTES.rst
%{python3_sitearch}/blosc-%{version}-py*.egg-info
%{python3_sitearch}/blosc/

%changelog
* Tue May 19 2015 toddrme2178@gmail.com
- Update to version 1.2.7
  * Updated to c-blosc v1.6.1.
* Sun Apr 26 2015 arun@gmx.de
- specfile:
  * added tests
* Thu Apr 23 2015 arun@gmx.de
- specfile:
  * update copyright year
- update to version 1.2.5:
  * Updated to c-blosc v1.5.4.
  * Added wrapper for the expert function set_blocksize. (#72 @esc)
  * Fix setup.py to allow compilation on posix architectures without
    SSE2. (#70 @andreas-schwab)
  * Don't release the GIL on compression/decompression (#77 @esc)
  * Various miscellaneous fixes
* Thu Jul 17 2014 toddrme2178@gmail.com
- Update to 1.2.4
  - Updated to c-blosc 1.4.0.  This added support for non-Intel
    architectures, most specially those not supporting unaligned access.
* Thu May  8 2014 toddrme2178@gmail.com
- Update to 1.2.3
  - Updated to c-blosc 1.3.5.  This removed a 'pointer from integer
    without a cast' compiler warning due to a bad macro definition.
- Update to 1.2.2
  - Updated to c-blosc 1.3.4.  This fixed a false buffer overrun
    condition.  This bug made c-blosc (and hence python-blosc) to fail,
    even if the failure was not real.
- Update to 1.2.1
  - Updated to c-blosc 1.3.3.
  - Added a new `cname2clib` map for programatically determine the library
    associated to a compressor.
  - New `get_clib(cbuffer)` that tells which compression library format
    has been used to created the compressed `cbuffer`.
- Update to 1.2.0
  - This release adds support for the multiple compressors added in Blosc
    1.3 series.
  - Added new `cname` parameter in compression functions like
    `compress()`, `compress_ptr()` and `pack_array()`.
  - Added a new utility function named `compressor_list()` that returns
    the list of compressors supported in the Blosc build.
  - Added 'bench/compress_ptr.py' for comparing times of the different
    compressors in Blosc and NumPy.
- Update to 1.1.0
  - Added new `compress_ptr` and `decompress_ptr` functions that allows to
    compress and decompress from/to a data pointer.  These are low level
    calls and user must make sure that the pointer data area is safe.
  - Since Blosc (the C library) already supports to be installed as an
    standalone library (via cmake), it is also possible to link
    python-blosc against a system Blosc library.
  - The Python calls to Blosc are now thread-safe (another consequence of
    recent Blosc library supporting this at C level).
  - Many checks on types and ranges of values have been added.  Most of
    the calls will now complain when passed the wrong values.
  - Docstrings are much improved. Also, Sphinx-based docs are available
    now.
- Update to 1.0.6
  - Fix compile error with msvc compilers.  Thanks to Christoph Gohlke.
- Update to 1.0.5
  - Upgraded to latest Blosc 1.1.4.
  - Better handling of condition errors, and improved memory releasing in
    case of errors (thanks to Valentin Haenel and Han Genuit).
  - Better handling of types (should compile without warning now, at least
    with GCC).
- Update to 1.0.4
  - Optimized the amount of data copied during compression (using
    _PyBytes_Resize() now instead of old PyBytes_FromStringAndSize()).
    This leads to improvements in compression speed ranging from 1.2x for
    highly compressible chunks up to 7x for mostly uncompressible data.
    Thanks to Valentin Haenel for this nice contribution.
- Use external blosc library.  The internal one builds a bad version
  of zlib.
* Fri Sep  7 2012 toddrme2178@gmail.com
- Initial version
